@@ -1,34 +1,36 @@
+from __future__ import unicode_literals
+
 from django.core.exceptions import ValidationError
+from django.conf import settings
 from django.db import models, DatabaseError, transaction
 from django.utils import simplejson as json
 from django.utils.translation import ugettext_lazy as _
+from django.utils import six
 
 from decimal import Decimal
 import datetime
 
-from utils import default
-from widgets import JSONWidget
-from forms import JSONFormField
+from .utils import default
+from .widgets import JSONWidget
+from .forms import JSONFormField
 
-class JSONField(models.Field):
+class JSONField(six.with_metaclass(models.SubfieldBase, models.Field)):
     """
     A field that will ensure the data entered into it is valid JSON.
     """
-    __metaclass__ = models.SubfieldBase
     default_error_messages = {
-        'invalid': _(u"'%s' is not a valid JSON string.")
+        'invalid': _("'%s' is not a valid JSON string.")
     }
     description = "JSON object"
     
     def __init__(self, *args, **kwargs):
         if not kwargs.get('null', False):
-            kwargs['default'] = kwargs.get('default', {})
+            kwargs['default'] = kwargs.get('default', dict)
+        self.encoder_kwargs = {
+            'indent': kwargs.get('indent', getattr(settings, 'JSONFIELD_INDENT', None))
+        }
         super(JSONField, self).__init__(*args, **kwargs)
-        if 'default' in kwargs:
-            if callable(self.default):
-                self.validate(self.default(), None)
-            else:
-                self.validate(self.default, None)
+        self.validate(self.get_default(), None)
         
     def formfield(self, **kwargs):
         defaults = {
@@ -48,9 +50,12 @@ class JSONField(models.Field):
 
     def get_default(self):
         if self.has_default():
-            if callable(self.default):
-                return self.default()
-            return self.default
+            default = self.default
+            if callable(default):
+                default = default()
+            if isinstance(default, six.string_types):
+                return json.loads(default)
+            return json.loads(json.dumps(default))
         return super(JSONField, self).get_default()
 
     def get_internal_type(self):
@@ -70,7 +75,7 @@ class JSONField(models.Field):
             return 'json'
     
     def to_python(self, value):
-        if isinstance(value, basestring):
+        if isinstance(value, six.string_types):
             if value == "":
                 if self.null:
                     return None
@@ -79,7 +84,7 @@ class JSONField(models.Field):
             try:
                 value = json.loads(value)
             except ValueError:
-                msg = self.error_messages['invalid'] % str(value)
+                msg = self.error_messages['invalid'] % value
                 raise ValidationError(msg)
         # TODO: Look for date/time/datetime objects within the structure?
         return value
@@ -92,7 +97,7 @@ class JSONField(models.Field):
             if not self.null and self.blank:
                 return ""
             return None
-        return json.dumps(value, default=default)
+        return json.dumps(value, default=default, **self.encoder_kwargs)
     
     def get_prep_lookup(self, lookup_type, value):
         if lookup_type in ["exact", "iexact"]:
